package
Version:
v1.0.3
Opens a new window with list of versions in this module.
Published: Nov 24, 2025
License: MIT
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
TenantId string `json:"tenantId"`
AppId string `json:"appId"`
Secret string `json:"secret"`
From string `json:"from"`
}
type Request struct {
To []string `json:"to"`
Cc []string `json:"cc"`
Bcc []string `json:"bcc"`
Subject string `json:"subject"`
Body string `json:"body"`
Attachments []send.Attachment `json:"attachments"`
Configuration Config `json:"configuration"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.